@@ -37,6 +37,7 @@ __all__ = (
     "ListTablesResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
+    "SqlParameterTypeDef",
     "StatementDataTypeDef",
     "TableMemberTypeDef",
 )
@@ -85,6 +86,7 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "Duration": int,
         "Error": str,
         "HasResultSet": bool,
+        "QueryParameters": List["SqlParameterTypeDef"],
         "QueryString": str,
         "RedshiftPid": int,
         "RedshiftQueryId": int,
@@ -232,6 +234,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+SqlParameterTypeDef = TypedDict(
+    "SqlParameterTypeDef",
+    {
+        "name": str,
+        "value": str,
+    },
+)
+
 _RequiredStatementDataTypeDef = TypedDict(
     "_RequiredStatementDataTypeDef",
     {
@@ -242,6 +252,7 @@ _OptionalStatementDataTypeDef = TypedDict(
     "_OptionalStatementDataTypeDef",
     {
         "CreatedAt": datetime,
+        "QueryParameters": List["SqlParameterTypeDef"],
         "QueryString": str,
         "SecretArn": str,
         "StatementName": str,
